@@ -8,7 +8,7 @@ from muffin.plugins import BasePlugin
 from apiclient import APIClient
 
 
-__version__ = "3.4.0"
+__version__ = "3.5.0"
 __project__ = "muffin-apiclient"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -81,4 +81,5 @@ class Plugin(BasePlugin):
 
     def request(self, *args, **kwargs) -> t.Awaitable:
         """Make a request."""
-        return self.client.request(*args, **kwargs)
+        client = t.cast(APIClient, self.client)
+        return client.request(*args, **kwargs)
